==> huaweicloudsdkelb-3.1.109-py2.py3-none-any.whl: huaweicloudsdkelb/v3/model/batch_add_available_zones_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchAddAvailableZonesRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'availability_zone_list': 'list[str]'
    }

    attribute_map = {
        'availability_zone_list': 'availability_zone_list'
    }

    def __init__(self, availability_zone_list=None):
        """BatchAddAvailableZonesRequestBody

        The model defined in huaweicloud sdk

        :param availability_zone_list: 新增的可用区列表，不能为空。
        :type availability_zone_list: list[str]
        """
        
        

        self._availability_zone_list = None
        self.discriminator = None

        self.availability_zone_list = availability_zone_list

    @property
    def availability_zone_list(self):
        """Gets the availability_zone_list of this BatchAddAvailableZonesRequestBody.

        新增的可用区列表，不能为空。

        :return: The availability_zone_list of this BatchAddAvailableZonesRequestBody.
        :rtype: list[str]
        """
        return self._availability_zone_list

    @availability_zone_list.setter
    def availability_zone_list(self, availability_zone_list):
        """Sets the availability_zone_list of this BatchAddAvailableZonesRequestBody.

        新增的可用区列表，不能为空。

        :param availability_zone_list: The availability_zone_list of this BatchAddAvailableZonesRequestBody.
        :type availability_zone_list: list[str]
        """
        self._availability_zone_list = availability_zone_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchAddAvailableZonesRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkelb-3.1.152-py2.py3-none-any.whl: huaweicloudsdkelb/v3/model/batch_add_available_zones_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchAddAvailableZonesRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'availability_zone_list': 'list[str]'
    }

    attribute_map = {
        'availability_zone_list': 'availability_zone_list'
    }

    def __init__(self, availability_zone_list=None):
        r"""BatchAddAvailableZonesRequestBody

        The model defined in huaweicloud sdk

        :param availability_zone_list: 新增的可用区列表，不能为空。
        :type availability_zone_list: list[str]
        """
        
        

        self._availability_zone_list = None
        self.discriminator = None

        self.availability_zone_list = availability_zone_list

    @property
    def availability_zone_list(self):
        r"""Gets the availability_zone_list of this BatchAddAvailableZonesRequestBody.

        新增的可用区列表，不能为空。

        :return: The availability_zone_list of this BatchAddAvailableZonesRequestBody.
        :rtype: list[str]
        """
        return self._availability_zone_list

    @availability_zone_list.setter
    def availability_zone_list(self, availability_zone_list):
        r"""Sets the availability_zone_list of this BatchAddAvailableZonesRequestBody.

        新增的可用区列表，不能为空。

        :param availability_zone_list: The availability_zone_list of this BatchAddAvailableZonesRequestBody.
        :type availability_zone_list: list[str]
        """
        self._availability_zone_list = availability_zone_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchAddAvailableZonesRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
